@@ -1,6 +1,6 @@
 package Encode::JP::Mobile;
 use strict;
-our $VERSION = "0.25";
+our $VERSION = "0.26";
 
 use Carp;
 use Encode;
@@ -33,6 +33,7 @@ define_alias( 'x-utf8-vodafone' => 'x-utf8-softbank' );
 
 use Encode::JP::Mobile::Vodafone;
 use Encode::JP::Mobile::KDDIJIS;
+use Encode::JP::Mobile::AirHJIS;
 use Encode::JP::Mobile::ConvertPictogramSJIS;
 require Encode::JP::Mobile::Fallback;
 require Encode::JP::Mobile::Character;
@@ -237,6 +238,14 @@ I<x-sjis-airedge> は I<x-sjis-docomo> の別名、として考えておくと
 
 SoftBank および KDDI/AU の絵文字は適切な DoCoMo 絵文字(ウェブ入力用絵文字)にマッピングされます。
 
+=item x-iso-2022-jp-airh
+
+AirEDGE から送られる絵文字入りのメールを変換するためのエンコーディングです。
+
+AirEDGE から送られるメールは通常のメールと同様に I<iso-2022-jp> がベースとなっていますが、絵文字部分のみ I<x-sjis-docomo-raw> という独自仕様になっており、これはその混在したメールを変換するためのエンコーディングになります。
+
+C<x-iso-2022-jp-airedge>をエイリアスとして利用できます。
+
 =item x-utf8-docomo, x-utf8-softbank, x-utf8-kddi
 
 これらのエンコーディングは、Unicode 私用領域にある各キャリアの絵文字を相互変換しながら UTF-8 互換のエンコーディングにエンコードするのに使用します。utf-8 という名前がついていますが、実際にはすべての Unicode 文字をエンコードするわけではなく、サブセットとして、
